-- Daily Global Check
-- by Jadya
-- EU-Well of Eternity

-- [[ Blizzard Interface Options Panels ]]--

local addonTitle, addonTable = ...
local L = addonTable.L

local options = DailyGlobalCheck.OptFunctions

local addontitle = "|TInterface\\icons\\INV_Sigil_Freya:16 |t|cff00AAFFDaily Global Check|r"


local function createOptionsFrame(p)

 local of = CreateFrame("Frame", "DGCOOptionsFrame", p)
 of:SetAllPoints()
 
 local chkmap_child 
 local chkcounter = 2

 local function CreateCheckbox(opt, text)
 
  local function OnOptionChanged(opt)
   if opt == "show_mapicons" or opt == "show_mapicons_all" then
    addonTable.forcemapupdate()
   end
  end

  local f = CreateFrame("CheckButton", "DGC_OptCheckbox"..chkcounter, of, "OptionsCheckButtonTemplate")
  table.insert(of.checkboxes, f)
   local txt = _G[f:GetName().."Text"]
   txt:SetText(text)
   txt:SetWordWrap(true)
   txt:SetWidth(p:GetWidth() - f:GetWidth() - 10)
   f:SetPoint("TOPLEFT", of, "TOPLEFT", 10, -20 * chkcounter)
   f:SetScript("OnClick", function()
    if opt == "minimap_icon" then
      DailyGlobalCheck_Options["minimap_icon"].hide = not f:GetChecked()
 	 addonTable.ldbicon:Refresh("DailyGlobalCheck_broker", DailyGlobalCheck_broker, DailyGlobalCheck_Options["minimap_icon"])
    else
     DailyGlobalCheck_Options[opt] = f:GetChecked()
	 if opt == "show_mapicons" then
      chkmap_child:SetEnabled(DailyGlobalCheck_Options[opt])
	 end
	 OnOptionChanged(opt)
	 addonTable.refresh()
    end
  end)
 
  if opt == "minimap_icon" then
   f:SetChecked(not DailyGlobalCheck_Options["minimap_icon"].hide)
  else
   f:SetChecked(DailyGlobalCheck_Options[opt])
  end
  chkcounter = chkcounter + 1
  return f
 end

 of.checkboxes = {}
 CreateCheckbox("minimap_icon",L["opt_minimap"])
 chkcounter = chkcounter + 1
 CreateCheckbox("show_questtype", L["opt_questtype"])
 CreateCheckbox("show_prefix", L["opt_prefix"])
 CreateCheckbox("show_zone", L["opt_zonename"])
 CreateCheckbox("show_suffix", L["opt_suffix"])
 CreateCheckbox("show_coordinates", L["opt_coords"])
 chkcounter = chkcounter + 2
 CreateCheckbox("show_questlogbtn", L["opt_showquestbtn"])
 chkcounter = chkcounter + 2
 CreateCheckbox("show_mapicons", L["opt_map"])
 chkcounter = chkcounter + 1
 chkmap_child = CreateCheckbox("show_mapicons_all", L["opt_map_all"])
 chkmap_child:SetEnabled(DailyGlobalCheck_Options["show_mapicons"])
 return of
end

local function createCharactersFrame(p)

 local of = CreateFrame("Frame", "DGCOCharsFrame", p)
 of:SetAllPoints()
 

 of.lblblacklist = of:CreateFontString(nil, "OVERLAY", "GameTooltipText")
 of.lblblacklist:SetPoint("TOPLEFT", of, "TOPLEFT", 10, -50)
 of.lblblacklist:SetText(L["opt_blacklist_remove"])
 of.lblblacklist:SetWordWrap(true)
 of.lblblacklist:SetWidth(p:GetWidth() - 20)

 of.ddblacklist = CreateFrame("Button", "DropDownMenuTest", of, "UIDropDownMenuTemplate")
 of.ddblacklist:SetPoint("TOPLEFT", of.lblblacklist, "BOTTOMLEFT", 0, -10)
 
 local function ddonclick(self)
   local t = DailyGlobalCheck_Options["chars_blacklist"]
   local pid = self.value
   
   local i = -1
   foreach(t, function(k,v) if v == pid then i = k return end end)
   
   if i > -1 then
    table.remove(t, i)
	self.disabled = true
	print(string.format(L["chars_restored"], pid))
   end
 end

 local function initialize(self, level)
   local info = UIDropDownMenu_CreateInfo()
   for k,v in pairs(DailyGlobalCheck_Options["chars_blacklist"]) do
      info = UIDropDownMenu_CreateInfo()
      info.text = v
      info.value = v
      info.func = ddonclick
      UIDropDownMenu_AddButton(info, level)
   end
 end
 
 of:SetScript("OnShow", function()
    UIDropDownMenu_Initialize(of.ddblacklist, initialize)
   end)
 
 return of
end

local function createHelpFrame(p)

 local of = CreateFrame("Frame", "DGCOHelpFrame", p)
 of:SetAllPoints()
 
 local t = of:CreateFontString(nil, "OVERLAY", "GameTooltipText")
 t:SetPoint("TOPLEFT", of, "TOPLEFT", 10, -50)
 t:SetText("Soon™")
 t:SetWordWrap(true)
 t:SetWidth(p:GetWidth() - 20)
 return of
end

local frames_backdrop  = { bgFile = "Interface\\Buttons\\GreyscaleRamp64", 
                           edgeFile = "Interface\\Buttons\\WHITE8X8", 
						   edgeSize = 1
						   }

----------------
function options:CreateOptionsFrame(parent)
 local f = CreateFrame("Frame","DGCOptionsFrame",parent)
 f:SetFrameStrata("HIGH")
 f:SetBackdrop(frames_backdrop)
 f:SetBackdropColor(0.07,0.07,0.07,0.9)
 f:SetBackdropBorderColor(0.1,0.1,0.1,0.9)
 f:SetPoint("LEFT", parent, "RIGHT")
 f:SetHeight(380)
 f:SetWidth(200)

 local function onmouseup(self)
  for _,v in pairs(f.buttons) do
   v:SetBackdropColor(0,0,0,0.9)
   v.panel:Hide()
  end
  self:SetBackdropColor(0,1,0,0.9)
  self.panel:Show()
 end
 
 f.buttons = {}

 -- Options Frame
 f.Options = createOptionsFrame(f)
 
 local btn = addonTable:largebuttontemplate(f, GAMEOPTIONS_MENU, "")
 btn:SetBackdropColor(0,1,0,0.9)
 btn:SetPoint("TOPLEFT")
 btn.panel = f.Options
 btn:SetScript("OnMouseUp", onmouseup)
 f.buttons.btnopt = btn
 
 -- Characters Frame
 f.Characters = createCharactersFrame(f)
 f.Characters:Hide()

 btn = addonTable:largebuttontemplate(f, "Chars", "")
 btn:SetBackdropColor(0,0,0,0.9)
 btn:SetPoint("LEFT", f.buttons.btnopt, "RIGHT")
 btn.panel = f.Characters
 btn:SetScript("OnMouseUp", onmouseup)
 f.buttons.btnchars = btn

 -- Help Frame
 f.Help = createHelpFrame(f)
 f.Help:Hide()
 
 btn = addonTable:largebuttontemplate(f, "Help", "")
 btn:SetBackdropColor(0,0,0,0.9)
 btn:SetPoint("LEFT", f.buttons.btnchars, "RIGHT")
 btn.panel = f.Help
 btn:SetScript("OnMouseUp", onmouseup)
 f.buttons.btnhelp = btn

 f:Hide()
 return f
end